summaryrefslogtreecommitdiffstats
path: root/kalzium/src/spectrum.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/spectrum.h')
-rw-r--r--kalzium/src/spectrum.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalzium/src/spectrum.h b/kalzium/src/spectrum.h
index 090822a6..4d71837f 100644
--- a/kalzium/src/spectrum.h
+++ b/kalzium/src/spectrum.h
@@ -143,9 +143,9 @@ class Spectrum
TQString bandsAsHtml();
/**
* @return the parent element of this spectrum
*/
- Element* parentElement()
+ Element* tqparentElement()
{ return m_parentElement; }
private:
@@ -143,9 +143,9 @@ class Spectrum
TQString bandsAsHtml();
/**
- * @return the parent element of this spectrum
+ * @return the tqparent element of this spectrum
*/